@@ -462,6 +462,7 @@ typedef struct aecg {
 		uint8_t	 NumberOfStatements;
 		char 	 **Statements;
         } Section11;
+
 } aECG_TYPE;
 
 /****************************************************************************/
@@ -470,13 +471,13 @@ typedef struct aecg {
 /**                                                                        **/
 /****************************************************************************/
 
-/*
-        file access wrapper: use ZLIB (if available) or STDIO
- */ 	 
 #ifdef __cplusplus
 EXTERN_C {
 #endif 
 
+/*
+        file access wrapper: use ZLIB (if available) or STDIO
+ */
 HDRTYPE* 	ifopen(HDRTYPE* hdr, const char* mode );
 int 		ifclose(HDRTYPE* hdr);
 int             ifeof(HDRTYPE* hdr);
@@ -514,6 +515,10 @@ ATT_DEPREC int strcmpi(const char* str1, const char* str2); // use strcasecmp()
 ATT_DEPREC int strncmpi(const char* str1, const char* str2, size_t n); // use strncasecmp() instead
 #endif
 
+
+int month_string2int(const char *s);
+
+
 int u32cmp(const void *a, const void *b); 
 
 void biosigERROR(HDRTYPE *hdr, enum B4C_ERROR errnum, const char *errmsg);
@@ -557,7 +562,16 @@ int NumberOfChannels(HDRTYPE *hdr);
         rereferencing is applied
  ------------------------------------------------------------------------*/
 
+
+size_t reallocEventTable(HDRTYPE *hdr, size_t EventN);
+/*
+	allocate, and resize memory of event table
+ ------------------------------------------------------------------------*/
+
 void FreeGlobalEventCodeTable();
+/*
+	free memory allocated for global event code
+ ------------------------------------------------------------------------*/
 
 size_t	sread_raw(size_t START, size_t LEN, HDRTYPE* hdr, char flag);
 /* sread_raw: 
