@@ -1,7 +1,7 @@
 /*
 
     $Id: sopen_abf_read.c,v 1.2 2009-02-12 16:15:17 schloegl Exp $
-    Copyright (C) 2012,2013 Alois Schloegl <alois.schloegl@gmail.com>
+    Copyright (C) 2012,2013,2014,2015 Alois Schloegl <alois.schloegl@gmail.com>
 
     This file is part of the "BioSig for C/C++" repository 
     (biosig4c++) at http://biosig.sf.net/ 
@@ -31,9 +31,9 @@
 
 #include "../biosig-dev.h"
 
-#define ABFLONG uint32_t
+#define ABFLONG int32_t
 #include "axon_structs.h"	// ABF2
-#include "abfheadr.h"	// ABF1
+#include "abfheadr.h"		// ABF1
 
 
 /*
@@ -46,43 +46,48 @@ EXTERN_C void sread_atf(HDRTYPE* hdr) {
 	if (VERBOSE_LEVEL>6) fprintf(stdout,"SREAD ATF [%i,%i]\n",(unsigned)hdr->NRec, (unsigned)hdr->SPR);
 
 	if (hdr->AS.rawdata != NULL) return;
-	if (hdr->NRec * hdr->SPR > 0)
+	//if (hdr->NRec * hdr->SPR > 0)
 		hdr->AS.rawdata = malloc(hdr->NRec * hdr->SPR * hdr->AS.bpb);
 
 	ifseek(hdr, hdr->HeadLen, SEEK_SET);
 
-	size_t ll  = 512;
-	char *line = malloc(ll+1);
+	size_t ll;
+	char *line = NULL;
 
 	if (VERBOSE_LEVEL>6) fprintf(stdout,"SREAD ATF\n");
 
 	size_t ln = 0;
 	while (~ifeof(hdr)) {
+		if (line!=NULL) { free(line); line=NULL; }  // allocate line buffer as needed
 		ssize_t nc = getline(&line, &ll, hdr->FILE.FID);
 		if (nc < 0) break;
 
-		if (VERBOSE_LEVEL>8) fprintf(stdout,"SREAD ATF  %i\t<%s>\n",(unsigned)ln,line );
+		if (VERBOSE_LEVEL>8) fprintf(stdout,"SREAD ATF 2 %i\t<%s>\n",(unsigned)ln,line );
 
-		if ((size_t)(hdr->NRec * hdr->SPR) <= (ln+1) ) {
+		if ((hdr->NRec * hdr->SPR) <= (long)(ln+1) ) {
 			hdr->NRec = max(1024, ln*2);
 			hdr->AS.rawdata = realloc(hdr->AS.rawdata, hdr->NRec * hdr->SPR * hdr->AS.bpb);
 		}
 
+		if (VERBOSE_LEVEL>8) fprintf(stdout,"SREAD ATF 4 %i\t<%s>\n",(unsigned)ln,line );
+
 		char *str = strtok(line,"\t");
 		typeof(hdr->NS) k;
 		for (k = 0; k < hdr->NS; k++) {
 			*(double*)(hdr->AS.rawdata + ln*hdr->AS.bpb + hdr->CHANNEL[k].bi) = strtod(str, &str);
 			// extract next value
-			str = strtok(NULL,"\t");
+			//str = strtok(NULL,"\t");
 		}
+		if (VERBOSE_LEVEL>8) fprintf(stdout,"SREAD ATF 6 %i\t<%s>\n",(unsigned)ln,line );
+
 		ln++;
 	}
 	free(line);
+	ifclose(hdr);
 
 	hdr->NRec = ln;
 	hdr->AS.first  = 0;
 	hdr->AS.length = hdr->NRec;
-
 }
 
 EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {	
@@ -96,21 +101,33 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 
 	if (VERBOSE_LEVEL>7) fprintf(stdout,"sopen_abf_read 101\n");
 
+	if (VERBOSE_LEVEL>7) fprintf(stderr,"%s (line %i) %li %i %i %li\n",__FILE__,__LINE__,
+                sizeof(struct ABFFileHeader),ABF_OLDHEADERSIZE, ABF_HEADERSIZE,
+                offsetof(struct ABFFileHeader, lHeaderSize));
+
+	if (VERBOSE_LEVEL>7) fprintf(stderr,"%s (line %i) %i %li %i\n",__FILE__,__LINE__,
+		ABF_BLOCKSIZE, offsetof(struct ABFFileHeader, lDataSectionPtr),
+		ABF_BLOCKSIZE*lei32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lDataSectionPtr)) );
+
 		size_t count = hdr->HeadLen; 	
 		hdr->VERSION = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fFileVersionNumber));
 
-		hdr->HeadLen = (hdr->VERSION < 1.6) ? ABF_OLDHEADERSIZE : ABF_HEADERSIZE;
+		hdr->HeadLen = ABF_BLOCKSIZE * lei32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lDataSectionPtr));
 		if (count < hdr->HeadLen) {
 			hdr->AS.Header = (uint8_t*) realloc(hdr->AS.Header, hdr->HeadLen);
 			count         += ifread(hdr->AS.Header+count, 1, hdr->HeadLen-count, hdr);
 		}
+		if ( count < (hdr->VERSION < 1.6 ? ABF_OLDHEADERSIZE : ABF_HEADERSIZE)
+		  || count < hdr->HeadLen )
+		{
+			biosigERROR(hdr, B4C_INCOMPLETE_FILE, "Reading ABF Header block failed"); return;
+		}
 		hdr->HeadLen = count;
-		assert(hdr->HeadLen == leu32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lHeaderSize)));
 
 		{
 			struct tm t;
 			uint32_t u = leu32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lFileStartDate));
-				t.tm_year = u / 10000 - 1900;
+			t.tm_year = u / 10000 - 1900;
 			t.tm_mon  = (u % 10000)/100 - 1;
 			t.tm_mday = (u % 100);
 			u = leu32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lFileStartTime));
@@ -127,21 +144,26 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 		case 1: gdftyp = 16; break;
 		}
 
+	if (VERBOSE_LEVEL>7) fprintf(stderr,"%s (line %i)\n",__FILE__,__LINE__);
+
 		size_t slen;
 		slen = min(MAX_LENGTH_MANUF, sizeof(((struct ABFFileHeader*)(hdr->AS.Header))->sCreatorInfo));
 		slen = min(MAX_LENGTH_MANUF, ABF_CREATORINFOLEN);
 		strncpy(hdr->ID.Manufacturer._field, (char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sCreatorInfo), slen);
 		hdr->ID.Manufacturer._field[slen] = 0;
 		hdr->ID.Manufacturer.Name = hdr->ID.Manufacturer._field;
-		slen = min(MAX_LENGTH_RID, sizeof(((struct ABFFileHeader*)(hdr->AS.Header))->sFileComment));
-		strncpy(hdr->ID.Recording,(char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sFileComment), slen);
-		hdr->ID.Recording[slen] = 0;
+
+		if (hdr->Version > 1.5) {
+			slen = min(MAX_LENGTH_RID, sizeof(((struct ABFFileHeader*)(hdr->AS.Header))->sFileComment));
+			strncpy(hdr->ID.Recording,(char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sFileComment), slen);
+			hdr->ID.Recording[slen] = 0;
+		}
 
 		if (VERBOSE_LEVEL>7) {
 			fprintf(stdout,"sCreatorInfo:\t%s\n",hdr->AS.Header + offsetof(struct ABFFileHeader, sCreatorInfo));
 			fprintf(stdout,"_sFileComment:\t%s\n",hdr->AS.Header + offsetof(struct ABFFileHeader, _sFileComment));
-			fprintf(stdout,"sFileComment:\t%s\n",hdr->AS.Header + offsetof(struct ABFFileHeader, sFileComment));
-			fprintf(stdout,"sFileComment:\t%s\n",hdr->AS.Header + offsetof(struct ABFFileHeader, sFileComment));
+			if (hdr->Version > 1.5)
+				fprintf(stdout,"sFileComment:\t%s\n",hdr->AS.Header + offsetof(struct ABFFileHeader, sFileComment));
 
 
 			fprintf(stdout,"\nlHeaderSize:\t%i\n",lei32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lHeaderSize)));
@@ -179,6 +201,7 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 
 			fprintf(stdout,"\nchannel_count_acquired:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, channel_count_acquired)));
 			fprintf(stdout,"nADCNumChannels:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nADCNumChannels)));
+			fprintf(stdout,"fADCSampleInterval:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCSampleInterval)));
 			fprintf(stdout,"nDigitalDACChannel:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nDigitalDACChannel)));
 			fprintf(stdout,"nOperationMode:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nOperationMode)));
 			fprintf(stdout,"nDigitalEnable:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nDigitalEnable)));
@@ -204,6 +227,10 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 
 		}
 
+	if (VERBOSE_LEVEL>7) fprintf(stdout,"sopen_abf_read 201\n");
+	if (VERBOSE_LEVEL>7) fprintf(stderr,"%s (line %i)\n",__FILE__,__LINE__);
+
+
 		hdr->NS = lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nADCNumChannels));
 		if (lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nDigitalEnable)))
 			hdr->NS += lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nDigitalDACChannel));
@@ -218,43 +245,60 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 		uint32_t k1=0,k;	// ABF is 32 bits only, no need for more
 		for (k=0; k < ABF_ADCCOUNT + ABF_DACCOUNT; k++) {
 			CHANNEL_TYPE *hc = hdr->CHANNEL+k1;
-			hc->bufptr = NULL;
-			hc->LeadIdCode = 0;
 			if ((k < ABF_ADCCOUNT) && (lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nADCSamplingSeq) + 2 * k) >= 0)) {
 				hc->OnOff = 1;
-
+				hc->bufptr = NULL;
+				hc->LeadIdCode = 0;
 				int ll = min(ABF_ADCNAMELEN, MAX_LENGTH_LABEL);
 				strncpy(hc->Label, (char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sADCChannelName) + k*ABF_ADCNAMELEN, ll);
 				while (ll > 0 && isspace(hc->Label[--ll]));
 				hc->Label[ll+1] = 0;
-
-				char units[ABF_ADCUNITLEN+1]; {
+				char units[ABF_ADCUNITLEN+1];
+				{
 					memcpy(units, (char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sADCUnits) + k*ABF_ADCUNITLEN, ABF_ADCUNITLEN);
 					units[ABF_ADCUNITLEN] = 0;
 					int p=ABF_ADCUNITLEN; 	while ( (0<p) && isspace(units[--p])) units[p]=0;  // remove trailing white space
 					hc->PhysDimCode = PhysDimCode(units);
 				}
+				hc->Transducer[0] = '\0';
 				hc->LowPass  = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fSignalLowpassFilter) + 4 * k);
 				hc->HighPass = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fSignalHighpassFilter) + 4 * k);
+				hc->Notch    = NAN;
+				hc->TOffset  = NAN;
+				hc->XYZ[0]   = 0;
+				hc->XYZ[1]   = 0;
+				hc->XYZ[2]   = 0;
 				hc->GDFTYP   = gdftyp;
 				hc->SPR      = hdr->SPR;
 				hc->bi       = k1*GDFTYP_BITS[gdftyp]/8;
-
+				hc->bi8      = k1*GDFTYP_BITS[gdftyp];
 				double PhysMax = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCRange));
 				double DigMax  = (double)lei32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lADCResolution));
-				double fInstrumentScaleFactor = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fInstrumentScaleFactor) + 4 * k);
-				hc->Cal      = fInstrumentScaleFactor * PhysMax/DigMax;
-				hc->Off      = 0.0;
-				hc->DigMax   = DigMax-1.0;
+				double fTotalScaleFactor = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fInstrumentScaleFactor) + 4 * k)
+							 * lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCProgrammableGain) + 4 * k);
+				hc->Off      = -lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fInstrumentOffset) + 4 * k);
+				if (lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nSignalType) + 2 * k) != 0) {
+					hc->Off           -= lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fInstrumentOffset) + 4 * k);
+					fTotalScaleFactor *= lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fSignalGain) + 4 * k);
+				}
+				if (hdr->Version > 1.5 &&
+				    lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nTelegraphEnable) + 2 * k) != 0) 
+				{
+					fTotalScaleFactor *= lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fTelegraphAdditGain) + 4 * k);
+				}
+				hc->Cal      = PhysMax / (fTotalScaleFactor * DigMax);
+
+				hc->DigMax   =  DigMax-1.0;
 				hc->DigMin   = -hc->DigMax;
 				hc->PhysMax  = hc->DigMax * hc->Cal;
 				hc->PhysMin  = hc->DigMin * hc->Cal;
-
 				if (VERBOSE_LEVEL>7) {
 					fprintf(stdout,"==== CHANNEL %i [%s] ====\n",k,units);
+					fprintf(stdout,"nSignalType:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nSignalType) + 2 * k));
 					fprintf(stdout,"nADCPtoLChannelMap:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nADCPtoLChannelMap) + 2 * k));
 					fprintf(stdout,"nADCSamplingSeq:\t%i\n",lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nADCSamplingSeq) + 2 * k));
 					fprintf(stdout,"fADCProgrammableGain:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCProgrammableGain) + 4 * k));
+					fprintf(stdout,"fADCRange:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCRange) + 4 * k));
 
 					fprintf(stdout,"fADCDisplayAmplification:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCDisplayAmplification) + 4 * k));
 					fprintf(stdout,"fADCDisplayOffset:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fADCDisplayOffset) + 4 * k));
@@ -264,11 +308,12 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 					fprintf(stdout,"fSignalOffset:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fSignalOffset) + 4 * k));
 					fprintf(stdout,"fSignalLowpassFilter:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fSignalLowpassFilter) + 4 * k));
 					fprintf(stdout,"fSignalHighpassFilter:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fSignalHighpassFilter) + 4 * k));
+					if (hdr->Version > 1.5)
+						fprintf(stdout,"fTelegraphAdditGain:\t%f\n",lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fTelegraphAdditGain) + 4 * k));
 				}
 				k1++;
 			}
 			else if (k < ABF_ADCCOUNT) {
-				hc->OnOff = 0;
 				// do not increase k1;
 				if (VERBOSE_LEVEL>7) {
 					fprintf(stdout,"==== CHANNEL %i ====\n",k);
@@ -290,6 +335,8 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 			}
 			else if ( (k1 < ABF_ADCCOUNT+ABF_DACCOUNT) && (k < hdr->NS) ) {
 				hc->OnOff = 1;
+				hc->bufptr = NULL;
+				hc->LeadIdCode = 0;
 				strncpy(hc->Label, (char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sDACChannelName) + (k-ABF_ADCCOUNT)*ABF_DACNAMELEN,
 					min(ABF_DACNAMELEN,MAX_LENGTH_LABEL));
 				hc->Label[ABF_DACNAMELEN] = 0;
@@ -300,8 +347,18 @@ EXTERN_C void sopen_abf_read(HDRTYPE* hdr) {
 					int p=ABF_ADCUNITLEN; 	while ( (0<p) && isspace(units[--p])) units[p]=0;  // remove trailing white space
 					hc->PhysDimCode = PhysDimCode(units);
 				}
+				hc->Transducer[0] = '\0';
+				hc->HighPass = NAN;
+				hc->LowPass  = NAN;
+				hc->Notch    = NAN;
+				hc->TOffset  = NAN;
+				hc->XYZ[0]   = 0;
+				hc->XYZ[1]   = 0;
+				hc->XYZ[2]   = 0;
 				hc->GDFTYP   = gdftyp;
 				hc->SPR = hdr->SPR;
+				hc->bi       = k1*GDFTYP_BITS[gdftyp]/8;
+				hc->bi8      = k1*GDFTYP_BITS[gdftyp];
 
 				double PhysMax = lef32p(hdr->AS.Header + offsetof(struct ABFFileHeader, fDACRange));
 				double DigMax  = (double)lei32p(hdr->AS.Header + offsetof(struct ABFFileHeader, lDACResolution));
@@ -384,7 +441,7 @@ EXTERN_C void sopen_abf2_read(HDRTYPE* hdr) {
 
 	if (VERBOSE_LEVEL>7) fprintf(stdout,"sopen_abf2_read 101\n");
 
-	biosigERROR(hdr, B4C_FORMAT_UNSUPPORTED, "ABF2 format currently not supported"); return;
+//	biosigERROR(hdr, B4C_FORMAT_UNSUPPORTED, "ABF2 format currently not supported"); return;
 
 		fprintf(stdout,"Warning ABF2 v%4.2f: implementation is not complete!\n", hdr->VERSION);
 
@@ -407,6 +464,7 @@ EXTERN_C void sopen_abf2_read(HDRTYPE* hdr) {
 			hdr->T0 = tm_time2gdf_time(&t);
 		}
 
+		hdr->SPR = 1;
 		uint16_t gdftyp = 3;
 		switch (lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nDataFormat))) {
 		case 0: gdftyp = 3; break;
@@ -512,9 +570,11 @@ EXTERN_C void sopen_abf2_read(HDRTYPE* hdr) {
 		float fDACRange = lef32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, fDACRange));
 		int32_t lADCResolution = lei32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, lADCResolution));
 		int32_t lDACResolution = lei32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, lDACResolution));
+		hdr->SampleRate =  1e6 / lef32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, fADCSequenceInterval));
 
 		if (VERBOSE_LEVEL>7) {
 			fprintf(stdout,"nOperationMode:\t%i\n", lei16p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, nOperationMode)));
+			fprintf(stdout,"fADCSequenceInterval:\t%g\n", lef32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, fADCSequenceInterval)));
 			fprintf(stdout,"fSecondsPerRun:\t%g\n", lef32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, fSecondsPerRun)));
 			fprintf(stdout,"fSecondsPerRun:\t%g\n", lef32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, fSecondsPerRun)));
 			fprintf(stdout,"lNumSamplesPerEpisode:\t%i\n", lei32p(hdr->AS.auxBUF + offsetof(struct ABF_ProtocolInfo, lNumSamplesPerEpisode)));
@@ -555,7 +615,7 @@ EXTERN_C void sopen_abf2_read(HDRTYPE* hdr) {
 			hc->HighPass = lef32p(hdr->AS.auxBUF + S.uBytes*k + offsetof(struct ABF_ADCInfo, fSignalHighpassFilter));
 			hc->GDFTYP   = gdftyp;
 			hc->SPR      = hdr->SPR;
-			hc->bi       = k*GDFTYP_BITS[gdftyp]/8;
+			hc->bi       = k*GDFTYP_BITS[gdftyp] / 8;
 
 /*
 			strncpy(hc->Label, (char*)hdr->AS.Header + offsetof(struct ABFFileHeader, sADCChannelName) + k*ABF_ADCNAMELEN, min(ABF_ADCNAMELEN,MAX_LENGTH_LABEL));
@@ -608,6 +668,7 @@ if (VERBOSE_LEVEL>7) {
 		readABF2block(hdr->AS.Header + offsetof(struct ABF_FileInfo, AnnotationSection), hdr, &S);
 		readABF2block(hdr->AS.Header + offsetof(struct ABF_FileInfo, StatsSection), hdr, &S);
 
+
 /*
 		hdr->NS = lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nADCNumChannels));
 		if (lei16p(hdr->AS.Header + offsetof(struct ABFFileHeader, nDigitalEnable)))
